/* Copyright (C) 2017 by Bundesanstalt für Gewässerkunde
 * Software engineering by
 *  Björnsen Beratende Ingenieure GmbH
 *  Dr. Schumacher Ingenieurbüro für Wasser und Umwelt
 *
 * This file is Free Software under the GNU AGPL (>=v3)
 * and comes with ABSOLUTELY NO WARRANTY! Check out the
 * documentation coming with Dive4Elements River for details.
 */
package org.dive4elements.river.artifacts.sinfo.flowdepthminmax;

import java.util.Collection;

import org.dive4elements.river.artifacts.sinfo.common.AbstractSInfoCalculationResult;
import org.dive4elements.river.artifacts.sinfo.util.BedHeightInfo;
import org.dive4elements.river.artifacts.sinfo.util.WstInfo;

/**
 * Contains the results of a {@link FlowDepthCalculation}.
 *
 * @author Gernot Belger
 */
final class FlowDepthMinMaxCalculationResult extends AbstractSInfoCalculationResult<FlowDepthMinMaxRow> {

    private static final long serialVersionUID = 1L;

    private final BedHeightInfo minSounding;

    private final BedHeightInfo maxSounding;

    public FlowDepthMinMaxCalculationResult(final String label, final WstInfo wst, final BedHeightInfo minSounding, final BedHeightInfo maxSounding,
            final Collection<FlowDepthMinMaxRow> rows) {
        super(label, wst, rows);

        this.minSounding = minSounding;
        this.maxSounding = maxSounding;
    }

    public BedHeightInfo getMinSounding() {
        return this.minSounding;
    }

    public BedHeightInfo getMaxSounding() {
        return this.maxSounding;
    }

    public BedHeightInfo getAnySounding() {
        if (this.minSounding != null)
            return this.minSounding;

        return this.maxSounding;
    }
}